#!/usr/bin/env python3

import json
import subprocess
import re

def Run(cmd):
  subprocess.check_call(cmd, shell=True)

def RunAgainstBranch(branch, outfile, runs=12):
  tmpfile = "/tmp/bench-output.json"
  Run("rm -rf {}".format(tmpfile))
  Run("git checkout {}".format(branch))
  Run("bazel build -c opt :benchmark")

  Run("./bazel-bin/benchmark --benchmark_out_format=json --benchmark_out={} --benchmark_repetitions={}".format(tmpfile, runs))

  with open(tmpfile) as f:
    bench_json = json.load(f)

  with open(outfile, "w") as f:
    for run in bench_json["benchmarks"]:
      name = re.sub(r'^BM_', 'Benchmark', run["name"])
      if name.endswith("_mean") or name.endswith("_median") or name.endswith("_stddev"):
        continue
      values = (name, run["iterations"], run["cpu_time"])
      print("{} {} {} ns/op".format(*values), file=f)

RunAgainstBranch("master", "/tmp/old.txt")
RunAgainstBranch("decoder", "/tmp/new.txt")

Run("~/go/bin/benchstat /tmp/old.txt /tmp/new.txt")



"""The py_test() script for generated_file_staleness_test() rules.

Note that this file is preprocessed!  The INSERT_<...> text below is replaced
with the actual list of files before we actually run the script.
"""

from __future__ import absolute_import

from tools import staleness_test_lib
import unittest
import sys

file_list = """
  INSERT_FILE_LIST_HERE
""".split()

config = staleness_test_lib.Config(file_list)


class TestFilesMatch(unittest.TestCase):

  def testFilesMatch(self):
    errors = staleness_test_lib.CheckFilesMatch(config)
    self.assertFalse(errors, errors)


if len(sys.argv) > 1 and sys.argv[1] == "--fix":
  staleness_test_lib.FixFiles(config)
else:
  unittest.main()
